==> snips-sam-0.0.7.tgz: package/docs/reference/index.md <==
---
layout: default
title:  "Reference"
permalink: /reference/
---

In this section, you will find in-depth documents describing various parts of the Snips platform.

<hr class="doc" />

<div class="columns">
  <div class="column is-4">
    <h3>Snips Architecture</h3>
    <ul class="reference">
      {% include reference_link.html path='articles/platform-basics' title='Snips Platform Basics' %}
    </ul>
    <h3>Managing Assistants</h3>
    <ul class="reference">
      {% include reference_link.html path='articles/snipsfile/' title='The Snipsfile' %}
      {% include reference_link.html path='articles/snips-object/' title='The <code>snips</code> object' %}
      {% include reference_link.html path='articles/sam-api/' title='Sam API' %}
    </ul>
  </div>
  <div class="column is-4">
    <h3>Microphones</h3>
    <ul class="reference">
      {% include reference_link.html path='articles/microphones/recommendations' title='Microphone Recommendations' %}
      {% include reference_link.html path='articles/microphones/respeaker7' title='ReSpeaker 7-Mic Array' %}
      {% include reference_link.html path='articles/microphones/matrix-voice' title='Matrix Voice' %}
      {% include reference_link.html path='articles/microphones/jabra-speak' title='Jabra Speak series' %}
    </ul>
    <h3>Troubleshooting</h3>
    <ul class="reference">
      {% include reference_link.html path='articles/troubleshooting-assistants' title='Troubleshooting Assistants' %}
    </ul>
  </div>
  <div class="column is-4">
    <h3>Example Skills</h3>
    <ul class="reference">
        {% include reference_link.html path='tutorials/calculator/' title='Calculator' %}
        {% include reference_link.html path='tutorials/sonos/' title='Sonos' %}
    </ul>
    <h3>Other Resources</h3>
    <ul class="reference">
        {% include reference_link.html url='https://labs.snips.ai' title='Snips Labs' %}
        {% include reference_link.html url='https://github.com/snipsco/awesome-snips' title='Awesome Snips Resources' %}
        {% include reference_link.html url='https://medium.com/snips-ai/benchmarking-microphone-arrays-respeaker-conexant-microsemi-acuedge-matrix-creator-minidsp-950de8876fda' title='Microphone Array Benchmark' %}
    </ul>
  </div>
</div>

==> snips-sam-0.0.15.tgz: package/docs/reference/index.md <==
---
layout: default
title:  "Reference"
permalink: /reference/
---

In this section, you will find in-depth documents describing various parts of the Snips platform.

<hr class="doc" />

<div class="columns">
  <div class="column is-4">
    <!-- <h3>Snips Architecture</h3>
    <ul class="reference">
      {% include reference_link.html path='articles/platform-basics' title='Snips Platform Basics' %}
    </ul> -->
    <h3>Managing Assistants</h3>
    <ul class="reference">
      {% include reference_link.html path='articles/snipsfile/' title='The Snipsfile' %}
      {% include reference_link.html path='articles/snips-object/' title='The <code>snips</code> object' %}
      {% include reference_link.html path='articles/sam-api/' title='Sam API' %}
    </ul>
  </div>
  <div class="column is-4">
    <h3>Microphones</h3>
    <ul class="reference">
      <!-- {% include reference_link.html path='articles/microphones/recommendations' title='Microphone Recommendations' %} -->
      {% include reference_link.html path='articles/microphones/respeaker7' title='ReSpeaker 7-Mic Array' %}
      <!-- {% include reference_link.html path='articles/microphones/matrix-voice' title='Matrix Voice' %} -->
      {% include reference_link.html path='articles/microphones/jabra-speak' title='Jabra Speak series' %}
    </ul>
    <!-- <h3>Troubleshooting</h3>
    <ul class="reference">
      {% include reference_link.html path='articles/troubleshooting-assistants' title='Troubleshooting Assistants' %}
    </ul> -->
  </div>
  <div class="column is-4">
    <h3>Example Skills</h3>
    <ul class="reference">
        {% include reference_link.html path='tutorials/calculator/' title='Calculator' %}
        {% include reference_link.html path='tutorials/sonos/' title='Sonos' %}
    </ul>
    <h3>Other Resources</h3>
    <ul class="reference">
        {% include reference_link.html url='https://labs.snips.ai' title='Snips Labs' %}
        {% include reference_link.html url='https://github.com/snipsco/awesome-snips' title='Awesome Snips' %}
        {% include reference_link.html url='https://medium.com/snips-ai/benchmarking-microphone-arrays-respeaker-conexant-microsemi-acuedge-matrix-creator-minidsp-950de8876fda' title='Microphone Array Benchmark' %}
    </ul>
  </div>
</div>
